var structspa__thread__utils__methods =
[
    [ "version", "structspa__thread__utils__methods.html#a68878e9b02ee15f3590d4c871a97d74a", null ],
    [ "create", "structspa__thread__utils__methods.html#a22e5fb8af7bfdb9fe503f2562f5ed122", null ],
    [ "join", "structspa__thread__utils__methods.html#a32030849999e51af737dad5d2761c927", null ],
    [ "get_rt_range", "structspa__thread__utils__methods.html#a93b7072cec0d4898712b33c7a6808767", null ],
    [ "acquire_rt", "structspa__thread__utils__methods.html#a6423900a0115ed260e5d4b15f24285f5", null ],
    [ "drop_rt", "structspa__thread__utils__methods.html#a67cf4dee89855ce72ad3c48184e1ca01", null ]
];